package PlayBot::commands::get;

use strict;
use warnings;

use PlayBot::utils::print;
use PlayBot::utils::db;
use PlayBot::utils::db::get;

use PlayBot::commands::get::query;

our $irc;
our $log;

sub exec {
	my ($chan, $msg, $chan_src) = @_;

    my $query = PlayBot::commands::get::query->new(
        chan => $chan,
        query  => ($msg) ? $msg : ''
    );

    my $db_query = PlayBot::utils::db::get->new();
    my $rows = $db_query->get_rows($query);

    if (scalar @{$query->tags} == 0
            and scalar @{$query->words} > 0
            and $query->id == -1
            and $rows > 10
            and not $query->force)
    {
        $irc->yield(privmsg => $chan => "trop de résultats ($rows), utiliser -f pour forcer la recherche");
        return;
    }

    my $content = $db_query->get($query);

    if (!$content) {
        if ($rows > 0) {
            # the request was already executed, there is nothing more
            $irc->yield(privmsg => $chan => "Tu tournes en rond, Jack !");
        }
        elsif (@{$query->words} or @{$query->tags}) {
            $msg = "Je n'ai rien dans ce registre.";

            if (not $query->is_global) {
                # we check is there is result with global
                my $q = PlayBot::commands::get::query->new(
                    chan => $query->chan,
                    query  => $query->query . ' -a'
                );

                my $rows = $db_query->get_rows($q);
                if ($rows > 0) {
                    $msg .= ' ' . $rows . ' résultat';
                    $msg .= 's' if ($rows > 1);
                    $msg .= ' trouvé';
                    $msg .= 's' if ($rows > 1);
                    $msg .= ' avec une recherche globale.';
                }

            }

            $irc->yield(privmsg => $chan => $msg);
        }
        else {
            $irc->yield(privmsg => $chan => "Poste d'abord du contenu, n00b.");
        }

        return
    }

    my $dbh = PlayBot::utils::db::main_session();
    my $sth = $dbh->prepare("select tag
        from playbot_tags
        where id = ?
    ");
    $sth->execute($content->{id});

    my @tags;
    while (my $data = $sth->fetch) {
        my $tag = $data->[0];
        $tag =~ s/([a-zA-Z0-9_-]+)/#$1/;
        push @tags, $tag;
    }

    $content->{'tags'} = \@tags;

    my $irc_msg = PlayBot::utils::print::print($content);

    # if in query
    if ($chan !~ /^#/) {
        $irc_msg .= ' [' . $chan_src . ']';
    }
    else {
        $irc_msg .= ' [' . $rows . ' résultat';
        $irc_msg .= 's' if ($rows > 1);
        $irc_msg .= ']';
    }

    $irc->yield(privmsg => $chan => $irc_msg);

    # we save the get like a post
    $sth = $dbh->prepare('
        INSERT INTO playbot_chan (content, chan, sender_irc)
        VALUES (?,?,?)');
    $log->error("Couldn't prepare querie; aborting") unless (defined $sth);

    $sth->execute($content->{id}, $chan, "PlayBot")
        or $log->error("Couldn't finish transaction: " . $dbh->errstr);

    $dbh->commit();

    return $content->{id};
}


1;
