package PlayBot::sites::soundcloud;

use strict;
use warnings;

use LWP::UserAgent;
use JSON;
use URI::Find;
use Scalar::Util qw(looks_like_number);

my $root = 'http://api.soundcloud.com';
my $clientId = 'f4956716fe1a9dc9c3725af822963365';


sub regex 
{
    return qr#(?:^|[^!])https?://(?:www\.)?soundcloud.com/([a-zA-Z0-9_-]+/[a-zA-Z0-9_-]+)(?:\?.+)?#;
}


sub get {
    shift;
	my $id = shift;

	my $ua = LWP::UserAgent->new(
        timeout => 30,
        env_proxy   => 1,
    );

    my $response;
    if (looks_like_number($id))
    {
	    $response = $ua->get($root.'/tracks/'.$id.'?client_id='.$clientId);
    }
    else
    {
	    my $url = 'https://www.soundcloud.com/'.$id;
	    $response = $ua->get($root.'/resolve.json?url='.$url.'&client_id='.$clientId);
    }
	die($response->status_line) unless ($response->is_success);

	my $content = decode_json($response->decoded_content);
    my $infos = {
	    author      => $content->{'user'}->{'username'},
        external_id => $content->{'id'},
        duration    => int(0.5 + $content->{'duration'} / 1000),
        site        => 'soundcloud',
        title       => $content->{'title'},
	    url         => $content->{permalink_url},
    };

	if ($content->{'downloadable'}) {
		$infos->{'ddl'} = $content->{'download_url'};
	}
    
	return %{ $infos };
}

1;
